WebPlatform Docs ▲ Prism plugins

# How to use

No setup required, just include the plugin in your download and you’re good to go!

Tokens that currently link to documentation:

- HTML, MathML and SVG tags
- HTML, MathML and SVG non-namespaced attributes
- (Non-prefixed) CSS properties
- (Non-prefixed) CSS @rules
- (Non-prefixed) CSS pseudo-classes
- (Non-prefixed) CSS pseudo-elements (starting with `::`)

Beta: This plugin is still in beta. Please help make it better: Test it and report any false positives etc!

# Examples

## CSS

## HTML

## SVG